"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const api = require("../../../scw/api.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
const resourcePaginator = require("../../../scw/fetch/resource-paginator.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends api.API {
  /**
   * Create a new Project for an Organization. Deprecated in favor of Account
   * API v3. Generate a new Project for an Organization, specifying its
   * configuration including name and description.
   *
   * @deprecated
   * @param request - The request {@link CreateProjectRequest}
   * @returns A Promise of Project
   */
  createProject = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/account/v2/projects`
    },
    marshalling_gen.unmarshalProject
  );
  pageOfListProjects = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v2/projects`,
      urlParams: marshalling.urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_ids", request.projectIds]
      )
    },
    marshalling_gen.unmarshalListProjectsResponse
  );
  /**
   * List all Projects of an Organization. Deprecated in favor of Account API
   * v3. List all Projects of an Organization. The response will include the
   * total number of Projects as well as their associated Organizations, names
   * and IDs. Other information include the creation and update date of the
   * Project.
   *
   * @deprecated
   * @param request - The request {@link ListProjectsRequest}
   * @returns A Promise of ListProjectsResponse
   */
  listProjects = (request = {}) => resourcePaginator.enrichForPagination("projects", this.pageOfListProjects, request);
  /**
   * Get an existing Project. Deprecated in favor of Account API v3. Retrieve
   * information about an existing Project, specified by its Project ID. Its
   * full details, including ID, name and description, are returned in the
   * response object.
   *
   * @deprecated
   * @param request - The request {@link GetProjectRequest}
   * @returns A Promise of Project
   */
  getProject = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/account/v2/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    marshalling_gen.unmarshalProject
  );
  /**
   * Delete an existing Project. Deprecated in favor of Account API v3. Delete
   * an existing Project, specified by its Project ID. The Project needs to be
   * empty (meaning there are no resources left in it) to be deleted
   * effectively. Note that deleting a Project is permanent, and cannot be
   * undone.
   *
   * @deprecated
   * @param request - The request {@link DeleteProjectRequest}
   */
  deleteProject = (request = {}) => this.client.fetch({
    method: "DELETE",
    path: `/account/v2/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
  });
  /**
   * Update Project. Deprecated in favor of Account API v3. Update the
   * parameters of an existing Project, specified by its Project ID. These
   * parameters include the name and description.
   *
   * @deprecated
   * @param request - The request {@link UpdateProjectRequest}
   * @returns A Promise of Project
   */
  updateProject = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalUpdateProjectRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/account/v2/projects/${marshalling.validatePathParam("projectId", request.projectId ?? this.client.settings.defaultProjectId)}`
    },
    marshalling_gen.unmarshalProject
  );
}
exports.API = API;
