import { waitForResource } from "../../../internal/async/interval-retrier.js";
import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { SERVER_TRANSIENT_STATUSES, SERVER_INSTALL_TRANSIENT_STATUSES, BMC_ACCESS_TRANSIENT_STATUSES, RPN_SAN_TRANSIENT_STATUSES, RPN_V2_GROUP_TRANSIENT_STATUSES } from "./content.gen.js";
import { unmarshalListServersResponse, unmarshalServer, unmarshalBackup, marshalUpdateServerBackupRequest, unmarshalListSubscribableServerOptionsResponse, marshalSubscribeServerOptionRequest, unmarshalService, marshalCreateServerRequest, marshalSubscribeStorageOptionsRequest, unmarshalSubscribeStorageOptionsResponse, marshalUpdateServerRequest, marshalUpdateServerTagsRequest, unmarshalListServerEventsResponse, unmarshalListServerDisksResponse, unmarshalListServicesResponse, marshalInstallServerRequest, unmarshalServerInstall, unmarshalServerDefaultPartitioning, marshalStartBMCAccessRequest, unmarshalBMCAccess, unmarshalListOffersResponse, unmarshalOffer, unmarshalListOSResponse, unmarshalOS, marshalUpdateReverseRequest, unmarshalIP, marshalCreateFailoverIPsRequest, unmarshalCreateFailoverIPsResponse, marshalAttachFailoverIPsRequest, marshalDetachFailoverIPsRequest, marshalAttachFailoverIPToMacAddressRequest, unmarshalListFailoverIPsResponse, unmarshalFailoverIP, unmarshalGetRemainingQuotaResponse, unmarshalRaid, marshalUpdateRaidRequest, marshalStartRescueRequest, unmarshalRescue, unmarshalListInvoicesResponse, unmarshalInvoice, unmarshalListRefundsResponse, unmarshalRefund, unmarshalCanOrderResponse, unmarshalGetIPv6BlockQuotasResponse, marshalIPv6BlockApiCreateIPv6BlockRequest, unmarshalIPv6Block, marshalIPv6BlockApiUpdateIPv6BlockRequest, marshalIPv6BlockApiCreateIPv6BlockSubnetRequest, unmarshalListIPv6BlockSubnetsAvailableResponse, unmarshalListRpnServerCapabilitiesResponse, unmarshalGetRpnStatusResponse, unmarshalListRpnSansResponse, unmarshalRpnSan, marshalRpnSanApiCreateRpnSanRequest, unmarshalListIpsResponse, marshalRpnSanApiAddIpRequest, marshalRpnSanApiRemoveIpRequest, unmarshalListRpnGroupsResponse, unmarshalRpnGroup, marshalRpnV1ApiCreateRpnGroupRequest, marshalRpnV1ApiUpdateRpnGroupNameRequest, unmarshalListRpnGroupMembersResponse, marshalRpnV1ApiRpnGroupInviteRequest, marshalRpnV1ApiLeaveRpnGroupRequest, marshalRpnV1ApiAddRpnGroupMembersRequest, marshalRpnV1ApiDeleteRpnGroupMembersRequest, unmarshalListRpnCapableServersResponse, unmarshalListRpnCapableSanServersResponse, unmarshalListRpnInvitesResponse, unmarshalListRpnV2GroupsResponse, unmarshalListRpnV2MembersResponse, unmarshalRpnV2Group, marshalRpnV2ApiCreateRpnV2GroupRequest, marshalRpnV2ApiUpdateRpnV2GroupNameRequest, marshalRpnV2ApiAddRpnV2MembersRequest, marshalRpnV2ApiDeleteRpnV2MembersRequest, unmarshalListRpnV2CapableResourcesResponse, unmarshalListRpnV2GroupLogsResponse, marshalRpnV2ApiUpdateRpnV2VlanForMembersRequest, marshalRpnV2ApiEnableRpnV2GroupCompatibilityRequest } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available zones of the API. */
  static LOCALITIES = [
    "fr-par-1",
    "fr-par-2",
    "nl-ams-1"
  ];
  pageOfListServers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["search", request.search]
      )
    },
    unmarshalListServersResponse
  );
  /**
   * List baremetal servers for project.
   *
   * @param request - The request {@link ListServersRequest}
   * @returns A Promise of ListServersResponse
   */
  listServers = (request = {}) => enrichForPagination("servers", this.pageOfListServers, request);
  /**
   * Get a specific baremetal server. Get the server associated with the given
   * ID.
   *
   * @param request - The request {@link GetServerRequest}
   * @returns A Promise of Server
   */
  getServer = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}`
    },
    unmarshalServer
  );
  /**
   * Waits for {@link Server} to be in a final state.
   *
   * @param request - The request {@link GetServerRequest}
   * @param options - The waiting options
   * @returns A Promise of Server
   */
  waitForServer = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(!SERVER_TRANSIENT_STATUSES.includes(res.status))),
    this.getServer,
    request,
    options
  );
  getServerBackup = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/backups`
    },
    unmarshalBackup
  );
  updateServerBackup = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateServerBackupRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/backups`
    },
    unmarshalBackup
  );
  pageOfListSubscribableServerOptions = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/subscribable-server-options`,
      urlParams: urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListSubscribableServerOptionsResponse
  );
  /**
   * List subscribable server options. List subscribable options associated to
   * the given server ID.
   *
   * @param request - The request {@link ListSubscribableServerOptionsRequest}
   * @returns A Promise of ListSubscribableServerOptionsResponse
   */
  listSubscribableServerOptions = (request) => enrichForPagination(
    "serverOptions",
    this.pageOfListSubscribableServerOptions,
    request
  );
  /**
   * Subscribe server option. Subscribe option for the given server ID.
   *
   * @param request - The request {@link SubscribeServerOptionRequest}
   * @returns A Promise of Service
   */
  subscribeServerOption = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalSubscribeServerOptionRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/subscribe-server-option`
    },
    unmarshalService
  );
  /**
   * Create a baremetal server. Create a new baremetal server. The order return
   * you a service ID to follow the provisionning status you could call
   * GetService.
   *
   * @param request - The request {@link CreateServerRequest}
   * @returns A Promise of Service
   */
  createServer = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateServerRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers`
    },
    unmarshalService
  );
  /**
   * Subscribe storage server option. Subscribe storage option for the given
   * server ID.
   *
   * @param request - The request {@link SubscribeStorageOptionsRequest}
   * @returns A Promise of SubscribeStorageOptionsResponse
   */
  subscribeStorageOptions = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalSubscribeStorageOptionsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/subscribe-storage-options`
    },
    unmarshalSubscribeStorageOptionsResponse
  );
  /**
   * Update a baremetal server. Update the server associated with the given ID.
   *
   * @param request - The request {@link UpdateServerRequest}
   * @returns A Promise of Server
   */
  updateServer = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateServerRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}`
    },
    unmarshalServer
  );
  updateServerTags = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateServerTagsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/tags`
    },
    unmarshalServer
  );
  /**
   * Reboot a baremetal server. Reboot the server associated with the given ID,
   * use boot param to reboot in rescue.
   *
   * @param request - The request {@link RebootServerRequest}
   */
  rebootServer = (request) => this.client.fetch({
    body: "{}",
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/reboot`
  });
  /**
   * Start a baremetal server. Start the server associated with the given ID.
   *
   * @param request - The request {@link StartServerRequest}
   */
  startServer = (request) => this.client.fetch({
    body: "{}",
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/start`
  });
  /**
   * Stop a baremetal server. Stop the server associated with the given ID.
   *
   * @param request - The request {@link StopServerRequest}
   */
  stopServer = (request) => this.client.fetch({
    body: "{}",
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/stop`
  });
  /**
   * Delete a baremetal server. Delete the server associated with the given ID.
   *
   * @param request - The request {@link DeleteServerRequest}
   */
  deleteServer = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}`
  });
  pageOfListServerEvents = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/events`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListServerEventsResponse
  );
  /**
   * List server events. List events associated to the given server ID.
   *
   * @param request - The request {@link ListServerEventsRequest}
   * @returns A Promise of ListServerEventsResponse
   */
  listServerEvents = (request) => enrichForPagination("events", this.pageOfListServerEvents, request);
  pageOfListServerDisks = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/disks`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListServerDisksResponse
  );
  /**
   * List server disks. List disks associated to the given server ID.
   *
   * @param request - The request {@link ListServerDisksRequest}
   * @returns A Promise of ListServerDisksResponse
   */
  listServerDisks = (request) => enrichForPagination("disks", this.pageOfListServerDisks, request);
  getOrderedService = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/ordered-services/${validatePathParam("orderedServiceId", request.orderedServiceId)}`
    },
    unmarshalService
  );
  /**
   * Get a specific service. Get the service associated with the given ID.
   *
   * @param request - The request {@link GetServiceRequest}
   * @returns A Promise of Service
   */
  getService = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/services/${validatePathParam("serviceId", request.serviceId)}`
    },
    unmarshalService
  );
  /**
   * Delete a specific service. Delete the service associated with the given ID.
   *
   * @param request - The request {@link DeleteServiceRequest}
   * @returns A Promise of Service
   */
  deleteService = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/services/${validatePathParam("serviceId", request.serviceId)}`
    },
    unmarshalService
  );
  pageOfListServices = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/services`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListServicesResponse
  );
  /**
   * List services.
   *
   * @param request - The request {@link ListServicesRequest}
   * @returns A Promise of ListServicesResponse
   */
  listServices = (request = {}) => enrichForPagination("services", this.pageOfListServices, request);
  /**
   * Install a baremetal server. Install an OS on the server associated with the
   * given ID.
   *
   * @param request - The request {@link InstallServerRequest}
   * @returns A Promise of ServerInstall
   */
  installServer = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalInstallServerRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/install`
    },
    unmarshalServerInstall
  );
  /**
   * Get a specific server installation status. Get the server installation
   * status associated with the given server ID.
   *
   * @param request - The request {@link GetServerInstallRequest}
   * @returns A Promise of ServerInstall
   */
  getServerInstall = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/install`
    },
    unmarshalServerInstall
  );
  /**
   * Waits for {@link ServerInstall} to be in a final state.
   *
   * @param request - The request {@link GetServerInstallRequest}
   * @param options - The waiting options
   * @returns A Promise of ServerInstall
   */
  waitForServerInstall = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !SERVER_INSTALL_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getServerInstall,
    request,
    options
  );
  /**
   * Cancels the current (running) server installation. Cancels the current
   * server installation associated with the given server ID.
   *
   * @param request - The request {@link CancelServerInstallRequest}
   */
  cancelServerInstall = (request) => this.client.fetch({
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/cancel-install`
  });
  /**
   * Get server default partitioning. Get the server default partitioning schema
   * associated with the given server ID and OS ID.
   *
   * @param request - The request {@link GetServerDefaultPartitioningRequest}
   * @returns A Promise of ServerDefaultPartitioning
   */
  getServerDefaultPartitioning = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/partitioning/${validatePathParam("osId", request.osId)}`
    },
    unmarshalServerDefaultPartitioning
  );
  /**
   * Start BMC (Baseboard Management Controller) access for a given baremetal
   * server. Start BMC (Baseboard Management Controller) access associated with
   * the given ID. The BMC (Baseboard Management Controller) access is available
   * one hour after the installation of the server.
   *
   * @param request - The request {@link StartBMCAccessRequest}
   */
  startBMCAccess = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalStartBMCAccessRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/bmc-access`
  });
  /**
   * Get BMC (Baseboard Management Controller) access for a given baremetal
   * server. Get the BMC (Baseboard Management Controller) access associated
   * with the given ID.
   *
   * @param request - The request {@link GetBMCAccessRequest}
   * @returns A Promise of BMCAccess
   */
  getBMCAccess = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/bmc-access`
    },
    unmarshalBMCAccess
  );
  /**
   * Waits for {@link BMCAccess} to be in a final state.
   *
   * @param request - The request {@link GetBMCAccessRequest}
   * @param options - The waiting options
   * @returns A Promise of BMCAccess
   */
  waitForBMCAccess = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(!BMC_ACCESS_TRANSIENT_STATUSES.includes(res.status))),
    this.getBMCAccess,
    request,
    options
  );
  /**
   * Stop BMC (Baseboard Management Controller) access for a given baremetal
   * server. Stop BMC (Baseboard Management Controller) access associated with
   * the given ID.
   *
   * @param request - The request {@link StopBMCAccessRequest}
   */
  stopBMCAccess = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/bmc-access`
  });
  pageOfListOffers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/offers`,
      urlParams: urlParams(
        ["available_only", request.availableOnly],
        ["catalog", request.catalog],
        ["commercial_range", request.commercialRange],
        ["is_failover_block", request.isFailoverBlock],
        ["is_failover_ip", request.isFailoverIp],
        ["is_rpn_san", request.isRpnSan],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        [
          "sold_in",
          request.soldIn && request.soldIn.length > 0 ? request.soldIn.join(",") : void 0
        ]
      )
    },
    unmarshalListOffersResponse
  );
  /**
   * List offers. List all available server offers.
   *
   * @param request - The request {@link ListOffersRequest}
   * @returns A Promise of ListOffersResponse
   */
  listOffers = (request = {}) => enrichForPagination("offers", this.pageOfListOffers, request);
  /**
   * Get offer. Return specific offer for the given ID.
   *
   * @param request - The request {@link GetOfferRequest}
   * @returns A Promise of Offer
   */
  getOffer = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/offers/${validatePathParam("offerId", request.offerId)}`,
      urlParams: urlParams(["project_id", request.projectId])
    },
    unmarshalOffer
  );
  pageOfListOS = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/os`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["server_id", request.serverId],
        ["type", request.type]
      )
    },
    unmarshalListOSResponse
  );
  /**
   * List all available OS that can be install on a baremetal server.
   *
   * @param request - The request {@link ListOSRequest}
   * @returns A Promise of ListOSResponse
   */
  listOS = (request) => enrichForPagination("os", this.pageOfListOS, request);
  /**
   * Get an OS with a given ID. Return specific OS for the given ID.
   *
   * @param request - The request {@link GetOSRequest}
   * @returns A Promise of OS
   */
  getOS = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/os/${validatePathParam("osId", request.osId)}`,
      urlParams: urlParams(
        ["project_id", request.projectId],
        ["server_id", request.serverId]
      )
    },
    unmarshalOS
  );
  /**
   * Update reverse of ip. Update reverse of ip associated with the given ID.
   *
   * @param request - The request {@link UpdateReverseRequest}
   * @returns A Promise of IP
   */
  updateReverse = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateReverseRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/reverses/${validatePathParam("ipId", request.ipId)}`
    },
    unmarshalIP
  );
  /**
   * Order failover IPs. Order X failover IPs.
   *
   * @param request - The request {@link CreateFailoverIPsRequest}
   * @returns A Promise of CreateFailoverIPsResponse
   */
  createFailoverIPs = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateFailoverIPsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips`
    },
    unmarshalCreateFailoverIPsResponse
  );
  /**
   * Attach failovers on baremetal server. Attach failovers on the server
   * associated with the given ID.
   *
   * @param request - The request {@link AttachFailoverIPsRequest}
   */
  attachFailoverIPs = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalAttachFailoverIPsRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/attach`
  });
  /**
   * Detach failovers on baremetal server. Detach failovers on the server
   * associated with the given ID.
   *
   * @param request - The request {@link DetachFailoverIPsRequest}
   */
  detachFailoverIPs = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalDetachFailoverIPsRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/detach`
  });
  /**
   * Attach a failover IP to a MAC address.
   *
   * @param request - The request {@link AttachFailoverIPToMacAddressRequest}
   * @returns A Promise of IP
   */
  attachFailoverIPToMacAddress = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalAttachFailoverIPToMacAddressRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/${validatePathParam("ipId", request.ipId)}/attach-to-mac-address`
    },
    unmarshalIP
  );
  /**
   * Detach a failover IP from a MAC address.
   *
   * @param request - The request {@link DetachFailoverIPFromMacAddressRequest}
   * @returns A Promise of IP
   */
  detachFailoverIPFromMacAddress = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/${validatePathParam("ipId", request.ipId)}/detach-from-mac-address`
    },
    unmarshalIP
  );
  /**
   * Delete a failover server. Delete the failover associated with the given ID.
   *
   * @param request - The request {@link DeleteFailoverIPRequest}
   */
  deleteFailoverIP = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/${validatePathParam("ipId", request.ipId)}`
  });
  pageOfListFailoverIPs = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips`,
      urlParams: urlParams(
        ["only_available", request.onlyAvailable],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["search", request.search]
      )
    },
    unmarshalListFailoverIPsResponse
  );
  /**
   * List failovers for project. List failovers servers for project.
   *
   * @param request - The request {@link ListFailoverIPsRequest}
   * @returns A Promise of ListFailoverIPsResponse
   */
  listFailoverIPs = (request = {}) => enrichForPagination("failoverIps", this.pageOfListFailoverIPs, request);
  /**
   * Get a specific baremetal server. Get the server associated with the given
   * ID.
   *
   * @param request - The request {@link GetFailoverIPRequest}
   * @returns A Promise of FailoverIP
   */
  getFailoverIP = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/failover-ips/${validatePathParam("ipId", request.ipId)}`
    },
    unmarshalFailoverIP
  );
  /**
   * Get remaining quota.
   *
   * @param request - The request {@link GetRemainingQuotaRequest}
   * @returns A Promise of GetRemainingQuotaResponse
   */
  getRemainingQuota = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/remaining-quota`,
      urlParams: urlParams(["project_id", request.projectId])
    },
    unmarshalGetRemainingQuotaResponse
  );
  /**
   * Get raid. Return raid for the given server ID.
   *
   * @param request - The request {@link GetRaidRequest}
   * @returns A Promise of Raid
   */
  getRaid = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/raid`
    },
    unmarshalRaid
  );
  /**
   * Update RAID. Update RAID associated with the given server ID.
   *
   * @param request - The request {@link UpdateRaidRequest}
   */
  updateRaid = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalUpdateRaidRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/update-raid`
  });
  /**
   * Start in rescue baremetal server. Start in rescue the server associated
   * with the given ID.
   *
   * @param request - The request {@link StartRescueRequest}
   * @returns A Promise of Rescue
   */
  startRescue = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalStartRescueRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/rescue`
    },
    unmarshalRescue
  );
  /**
   * Get rescue information. Return rescue information for the given server ID.
   *
   * @param request - The request {@link GetRescueRequest}
   * @returns A Promise of Rescue
   */
  getRescue = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/rescue`
    },
    unmarshalRescue
  );
  /**
   * Stop rescue on baremetal server. Stop rescue on the server associated with
   * the given ID.
   *
   * @param request - The request {@link StopRescueRequest}
   */
  stopRescue = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/zones/${validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/servers/${validatePathParam("serverId", request.serverId)}/rescue`
  });
}
class BillingAPI extends API$1 {
  pageOfListInvoices = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/invoices`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListInvoicesResponse
  );
  listInvoices = (request = {}) => enrichForPagination("invoices", this.pageOfListInvoices, request);
  getInvoice = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/invoices/${validatePathParam("invoiceId", request.invoiceId)}`
    },
    unmarshalInvoice
  );
  downloadInvoice = (request) => this.client.fetch({
    method: "GET",
    path: `/dedibox/v1/invoices/${validatePathParam("invoiceId", request.invoiceId)}/download`,
    urlParams: urlParams(["dl", 1]),
    responseType: "blob"
  });
  pageOfListRefunds = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/refunds`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRefundsResponse
  );
  listRefunds = (request = {}) => enrichForPagination("refunds", this.pageOfListRefunds, request);
  getRefund = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/refunds/${validatePathParam("refundId", request.refundId)}`
    },
    unmarshalRefund
  );
  downloadRefund = (request) => this.client.fetch({
    method: "GET",
    path: `/dedibox/v1/refunds/${validatePathParam("refundId", request.refundId)}/download`,
    urlParams: urlParams(["dl", 1]),
    responseType: "blob"
  });
  canOrder = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/can-order`,
      urlParams: urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    unmarshalCanOrderResponse
  );
}
class IPv6BlockAPI extends API$1 {
  /**
   * Get IPv6 block quota. Get IPv6 block quota with the given project ID. /48
   * one per organization. /56 link to your number of server. /64 link to your
   * number of failover IP.
   *
   * @param request - The request {@link IPv6BlockApiGetIPv6BlockQuotasRequest}
   * @returns A Promise of GetIPv6BlockQuotasResponse
   */
  getIPv6BlockQuotas = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/ipv6-block-quotas`,
      urlParams: urlParams(["project_id", request.projectId])
    },
    unmarshalGetIPv6BlockQuotasResponse
  );
  /**
   * Create IPv6 block for baremetal server. Create IPv6 block associated with
   * the given project ID.
   *
   * @param request - The request {@link IPv6BlockApiCreateIPv6BlockRequest}
   * @returns A Promise of IPv6Block
   */
  createIPv6Block = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalIPv6BlockApiCreateIPv6BlockRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/ipv6-block`
    },
    unmarshalIPv6Block
  );
  /**
   * Get a specific IPv6 block. Get the IPv6 block associated with the given ID.
   *
   * @param request - The request {@link IPv6BlockApiGetIPv6BlockRequest}
   * @returns A Promise of IPv6Block
   */
  getIPv6Block = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/ipv6-block`,
      urlParams: urlParams(["project_id", request.projectId])
    },
    unmarshalIPv6Block
  );
  /**
   * Update IPv6 block. Update DNS associated to IPv6 block. If DNS is used,
   * minimum of 2 is necessary and maximum of 5 (no duplicate).
   *
   * @param request - The request {@link IPv6BlockApiUpdateIPv6BlockRequest}
   * @returns A Promise of IPv6Block
   */
  updateIPv6Block = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalIPv6BlockApiUpdateIPv6BlockRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/ipv6-blocks/${validatePathParam("blockId", request.blockId)}`
    },
    unmarshalIPv6Block
  );
  /**
   * Delete IPv6 block. Delete IPv6 block subnet with the given ID.
   *
   * @param request - The request {@link IPv6BlockApiDeleteIPv6BlockRequest}
   */
  deleteIPv6Block = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/ipv6-blocks/${validatePathParam("blockId", request.blockId)}`
  });
  /**
   * Create IPv6 block subnet. Create IPv6 block subnet for the given IP ID. /48
   * could create subnet in /56 (quota link to your number of server). /56 could
   * create subnet in /64 (quota link to your number of failover IP).
   *
   * @param request - The request
   *   {@link IPv6BlockApiCreateIPv6BlockSubnetRequest}
   * @returns A Promise of IPv6Block
   */
  createIPv6BlockSubnet = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalIPv6BlockApiCreateIPv6BlockSubnetRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/ipv6-blocks/${validatePathParam("blockId", request.blockId)}/subnets`
    },
    unmarshalIPv6Block
  );
  /**
   * List available IPv6 block subnets. List all available IPv6 block subnets
   * for given IP ID.
   *
   * @param request - The request
   *   {@link IPv6BlockApiListIPv6BlockSubnetsAvailableRequest}
   * @returns A Promise of ListIPv6BlockSubnetsAvailableResponse
   */
  listIPv6BlockSubnetsAvailable = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/ipv6-blocks/${validatePathParam("blockId", request.blockId)}/subnets`
    },
    unmarshalListIPv6BlockSubnetsAvailableResponse
  );
}
class RpnAPI extends API$1 {
  pageOfListRpnServerCapabilities = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn/server-capabilities`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnServerCapabilitiesResponse
  );
  listRpnServerCapabilities = (request = {}) => enrichForPagination(
    "servers",
    this.pageOfListRpnServerCapabilities,
    request
  );
  getRpnStatus = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn/status`,
      urlParams: urlParams(
        ["project_id", request.projectId],
        ["rpnv1_group_id", request.rpnv1GroupId],
        ["rpnv2_group_id", request.rpnv2GroupId]
      )
    },
    unmarshalGetRpnStatusResponse
  );
}
class RpnSanAPI extends API$1 {
  pageOfListRpnSans = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn-sans`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnSansResponse
  );
  listRpnSans = (request = {}) => enrichForPagination("rpnSans", this.pageOfListRpnSans, request);
  getRpnSan = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}`
    },
    unmarshalRpnSan
  );
  /**
   * Waits for {@link RpnSan} to be in a final state.
   *
   * @param request - The request {@link RpnSanApiGetRpnSanRequest}
   * @param options - The waiting options
   * @returns A Promise of RpnSan
   */
  waitForRpnSan = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(!RPN_SAN_TRANSIENT_STATUSES.includes(res.status))),
    this.getRpnSan,
    request,
    options
  );
  deleteRpnSan = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}`
  });
  createRpnSan = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnSanApiCreateRpnSanRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/rpn-sans`
    },
    unmarshalService
  );
  listIps = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}/ips`,
      urlParams: urlParams(["type", request.type])
    },
    unmarshalListIpsResponse
  );
  addIp = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnSanApiAddIpRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}/ips`
  });
  removeIp = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnSanApiRemoveIpRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "DELETE",
    path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}/ips`
  });
  listAvailableIps = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpn-sans/${validatePathParam("rpnSanId", request.rpnSanId)}/available-ips`,
      urlParams: urlParams(["type", request.type])
    },
    unmarshalListIpsResponse
  );
}
class RpnV1API extends API$1 {
  pageOfListRpnGroups = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/groups`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnGroupsResponse
  );
  listRpnGroups = (request = {}) => enrichForPagination("rpnGroups", this.pageOfListRpnGroups, request);
  getRpnGroup = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}`
    },
    unmarshalRpnGroup
  );
  createRpnGroup = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV1ApiCreateRpnGroupRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/rpnv1/groups`
    },
    unmarshalRpnGroup
  );
  deleteRpnGroup = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}`
  });
  updateRpnGroupName = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV1ApiUpdateRpnGroupNameRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}`
    },
    unmarshalRpnGroup
  );
  pageOfListRpnGroupMembers = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}/members`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnGroupMembersResponse
  );
  listRpnGroupMembers = (request) => enrichForPagination("members", this.pageOfListRpnGroupMembers, request);
  rpnGroupInvite = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV1ApiRpnGroupInviteRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}/invite`
  });
  leaveRpnGroup = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV1ApiLeaveRpnGroupRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}/leave`
  });
  addRpnGroupMembers = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV1ApiAddRpnGroupMembersRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}/members`
    },
    unmarshalRpnGroup
  );
  deleteRpnGroupMembers = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV1ApiDeleteRpnGroupMembersRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "DELETE",
      path: `/dedibox/v1/rpnv1/groups/${validatePathParam("groupId", request.groupId)}/members`
    },
    unmarshalRpnGroup
  );
  pageOfListRpnCapableServers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/capable-servers`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnCapableServersResponse
  );
  listRpnCapableServers = (request = {}) => enrichForPagination("servers", this.pageOfListRpnCapableServers, request);
  pageOfListRpnCapableSanServers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/capable-san-servers`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnCapableSanServersResponse
  );
  listRpnCapableSanServers = (request = {}) => enrichForPagination(
    "sanServers",
    this.pageOfListRpnCapableSanServers,
    request
  );
  pageOfListRpnInvites = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv1/invites`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    unmarshalListRpnInvitesResponse
  );
  listRpnInvites = (request = {}) => enrichForPagination("members", this.pageOfListRpnInvites, request);
  acceptRpnInvite = (request) => this.client.fetch({
    method: "POST",
    path: `/dedibox/v1/rpnv1/invites/${validatePathParam("memberId", request.memberId)}/accept`
  });
  refuseRpnInvite = (request) => this.client.fetch({
    method: "POST",
    path: `/dedibox/v1/rpnv1/invites/${validatePathParam("memberId", request.memberId)}/refuse`
  });
}
class RpnV2API extends API$1 {
  pageOfListRpnV2Groups = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv2/groups`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnV2GroupsResponse
  );
  listRpnV2Groups = (request = {}) => enrichForPagination("rpnGroups", this.pageOfListRpnV2Groups, request);
  pageOfListRpnV2Members = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/members`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["type", request.type]
      )
    },
    unmarshalListRpnV2MembersResponse
  );
  listRpnV2Members = (request) => enrichForPagination("members", this.pageOfListRpnV2Members, request);
  getRpnV2Group = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}`
    },
    unmarshalRpnV2Group
  );
  /**
   * Waits for {@link RpnV2Group} to be in a final state.
   *
   * @param request - The request {@link RpnV2ApiGetRpnV2GroupRequest}
   * @param options - The waiting options
   * @returns A Promise of RpnV2Group
   */
  waitForRpnV2Group = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !RPN_V2_GROUP_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getRpnV2Group,
    request,
    options
  );
  createRpnV2Group = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV2ApiCreateRpnV2GroupRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/dedibox/v1/rpnv2/groups`
    },
    unmarshalRpnV2Group
  );
  deleteRpnV2Group = (request) => this.client.fetch({
    method: "DELETE",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}`
  });
  updateRpnV2GroupName = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRpnV2ApiUpdateRpnV2GroupNameRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}`
    },
    unmarshalRpnV2Group
  );
  addRpnV2Members = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV2ApiAddRpnV2MembersRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/members`
  });
  deleteRpnV2Members = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV2ApiDeleteRpnV2MembersRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "DELETE",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/members`
  });
  pageOfListRpnV2CapableResources = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv2/groups/capable`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListRpnV2CapableResourcesResponse
  );
  listRpnV2CapableResources = (request = {}) => enrichForPagination(
    "servers",
    this.pageOfListRpnV2CapableResources,
    request
  );
  pageOfListRpnV2GroupLogs = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/logs`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    unmarshalListRpnV2GroupLogsResponse
  );
  listRpnV2GroupLogs = (request) => enrichForPagination("logs", this.pageOfListRpnV2GroupLogs, request);
  updateRpnV2VlanForMembers = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV2ApiUpdateRpnV2VlanForMembersRequest(
        request,
        this.client.settings
      )
    ),
    headers: jsonContentHeaders,
    method: "PATCH",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/vlan`
  });
  enableRpnV2GroupCompatibility = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalRpnV2ApiEnableRpnV2GroupCompatibilityRequest(
        request,
        this.client.settings
      )
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/enable-compatibility`
  });
  disableRpnV2GroupCompatibility = (request) => this.client.fetch({
    body: "{}",
    headers: jsonContentHeaders,
    method: "POST",
    path: `/dedibox/v1/rpnv2/groups/${validatePathParam("groupId", request.groupId)}/disable-compatibility`
  });
}
export {
  API,
  BillingAPI,
  IPv6BlockAPI,
  RpnAPI,
  RpnSanAPI,
  RpnV1API,
  RpnV2API
};
