import { API as ParentAPI } from '../../../bridge';
import type { Region } from '../../../bridge';
import type { BookIPRequest, GetIPRequest, IP, ListIPsRequest, ListIPsResponse, ReleaseIPRequest, ReleaseIPSetRequest, UpdateIPRequest } from './types.gen';
/**
 * IPAM API.
 *
 * This API allows you to manage your Scaleway IP addresses with our IP Address
 * Management tool.
 */
export declare class API extends ParentAPI {
    /** Lists the available regions of the API. */
    static readonly LOCALITIES: Region[];
    /**
     * Book a new IP. Book a new IP from the specified source. Currently IPs can
     * only be booked from a Private Network.
     *
     * @param request - The request {@link BookIPRequest}
     * @returns A Promise of IP
     */
    bookIP: (request: Readonly<BookIPRequest>) => Promise<IP>;
    /**
     * Release an IP. Release an IP not currently attached to a resource, and
     * returns it to the available IP pool.
     *
     * @param request - The request {@link ReleaseIPRequest}
     */
    releaseIP: (request: Readonly<ReleaseIPRequest>) => Promise<void>;
    releaseIPSet: (request?: Readonly<ReleaseIPSetRequest>) => Promise<void>;
    /**
     * Get an IP. Retrieve details of an existing IP, specified by its IP ID.
     *
     * @param request - The request {@link GetIPRequest}
     * @returns A Promise of IP
     */
    getIP: (request: Readonly<GetIPRequest>) => Promise<IP>;
    /**
     * Update an IP. Update parameters including tags of the specified IP.
     *
     * @param request - The request {@link UpdateIPRequest}
     * @returns A Promise of IP
     */
    updateIP: (request: Readonly<UpdateIPRequest>) => Promise<IP>;
    protected pageOfListIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse>;
    /**
     * List existing IPs. List existing IPs in the specified region using various
     * filters. For example, you can filter for IPs within a specified Private
     * Network, or for public IPs within a specified Project. By default, the IPs
     * returned in the list are ordered by creation date in ascending order,
     * though this can be modified via the order_by field.
     *
     * @param request - The request {@link ListIPsRequest}
     * @returns A Promise of ListIPsResponse
     */
    listIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse> & {
        all: () => Promise<IP[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<IP[], void, void>;
    };
}
