import { isJSONObject } from "../../../helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject } from "../../../helpers/marshalling.js";
const unmarshalEmailTry = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EmailTry' failed as data isn't a dictionary.`
    );
  }
  return {
    code: data.code,
    message: data.message,
    rank: data.rank,
    triedAt: unmarshalDate(data.tried_at)
  };
};
const unmarshalEmail = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Email' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    flags: data.flags,
    id: data.id,
    lastTries: unmarshalArrayOfObject(data.last_tries, unmarshalEmailTry),
    mailFrom: data.mail_from,
    mailRcpt: data.mail_rcpt,
    messageId: data.message_id,
    projectId: data.project_id,
    rcptTo: data.rcpt_to,
    rcptType: data.rcpt_type,
    status: data.status,
    statusDetails: data.status_details,
    subject: data.subject,
    tryCount: data.try_count,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalDomainRecordsDMARC = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainRecordsDMARC' failed as data isn't a dictionary.`
    );
  }
  return {
    name: data.name,
    value: data.value
  };
};
const unmarshalDomainRecords = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainRecords' failed as data isn't a dictionary.`
    );
  }
  return {
    dmarc: data.dmarc ? unmarshalDomainRecordsDMARC(data.dmarc) : void 0
  };
};
const unmarshalDomainReputation = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainReputation' failed as data isn't a dictionary.`
    );
  }
  return {
    previousScore: data.previous_score,
    previousScoredAt: unmarshalDate(data.previous_scored_at),
    score: data.score,
    scoredAt: unmarshalDate(data.scored_at),
    status: data.status
  };
};
const unmarshalDomainStatistics = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainStatistics' failed as data isn't a dictionary.`
    );
  }
  return {
    canceledCount: data.canceled_count,
    failedCount: data.failed_count,
    sentCount: data.sent_count,
    totalCount: data.total_count
  };
};
const unmarshalDomain = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Domain' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    dkimConfig: data.dkim_config,
    id: data.id,
    lastError: data.last_error,
    lastValidAt: unmarshalDate(data.last_valid_at),
    name: data.name,
    nextCheckAt: unmarshalDate(data.next_check_at),
    organizationId: data.organization_id,
    projectId: data.project_id,
    records: data.records ? unmarshalDomainRecords(data.records) : void 0,
    region: data.region,
    reputation: data.reputation ? unmarshalDomainReputation(data.reputation) : void 0,
    revokedAt: unmarshalDate(data.revoked_at),
    spfConfig: data.spf_config,
    statistics: data.statistics ? unmarshalDomainStatistics(data.statistics) : void 0,
    status: data.status
  };
};
const unmarshalWebhook = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Webhook' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    domainId: data.domain_id,
    eventTypes: data.event_types,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    projectId: data.project_id,
    snsArn: data.sns_arn,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalCreateEmailResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CreateEmailResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    emails: unmarshalArrayOfObject(data.emails, unmarshalEmail)
  };
};
const unmarshalDomainLastStatusDkimRecord = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainLastStatusDkimRecord' failed as data isn't a dictionary.`
    );
  }
  return {
    error: data.error,
    lastValidAt: unmarshalDate(data.last_valid_at),
    status: data.status
  };
};
const unmarshalDomainLastStatusDmarcRecord = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainLastStatusDmarcRecord' failed as data isn't a dictionary.`
    );
  }
  return {
    error: data.error,
    lastValidAt: unmarshalDate(data.last_valid_at),
    status: data.status
  };
};
const unmarshalDomainLastStatusSpfRecord = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainLastStatusSpfRecord' failed as data isn't a dictionary.`
    );
  }
  return {
    error: data.error,
    lastValidAt: unmarshalDate(data.last_valid_at),
    status: data.status
  };
};
const unmarshalDomainLastStatus = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DomainLastStatus' failed as data isn't a dictionary.`
    );
  }
  return {
    dkimRecord: data.dkim_record ? unmarshalDomainLastStatusDkimRecord(data.dkim_record) : void 0,
    dmarcRecord: data.dmarc_record ? unmarshalDomainLastStatusDmarcRecord(data.dmarc_record) : void 0,
    domainId: data.domain_id,
    domainName: data.domain_name,
    spfRecord: data.spf_record ? unmarshalDomainLastStatusSpfRecord(data.spf_record) : void 0
  };
};
const unmarshalListDomainsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListDomainsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    domains: unmarshalArrayOfObject(data.domains, unmarshalDomain),
    totalCount: data.total_count
  };
};
const unmarshalListEmailsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListEmailsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    emails: unmarshalArrayOfObject(data.emails, unmarshalEmail),
    totalCount: data.total_count
  };
};
const unmarshalWebhookEvent = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'WebhookEvent' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    data: data.data,
    domainId: data.domain_id,
    emailId: data.email_id,
    id: data.id,
    organizationId: data.organization_id,
    projectId: data.project_id,
    status: data.status,
    type: data.type,
    updatedAt: unmarshalDate(data.updated_at),
    webhookId: data.webhook_id
  };
};
const unmarshalListWebhookEventsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListWebhookEventsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    webhookEvents: unmarshalArrayOfObject(
      data.webhook_events,
      unmarshalWebhookEvent
    )
  };
};
const unmarshalListWebhooksResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListWebhooksResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    webhooks: unmarshalArrayOfObject(data.webhooks, unmarshalWebhook)
  };
};
const unmarshalStatistics = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Statistics' failed as data isn't a dictionary.`
    );
  }
  return {
    canceledCount: data.canceled_count,
    failedCount: data.failed_count,
    newCount: data.new_count,
    sendingCount: data.sending_count,
    sentCount: data.sent_count,
    totalCount: data.total_count
  };
};
const marshalCreateDomainRequest = (request, defaults) => ({
  accept_tos: request.acceptTos,
  domain_name: request.domainName,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalCreateEmailRequestAddress = (request, defaults) => ({
  email: request.email,
  name: request.name
});
const marshalCreateEmailRequestAttachment = (request, defaults) => ({
  content: request.content,
  name: request.name,
  type: request.type
});
const marshalCreateEmailRequestHeader = (request, defaults) => ({
  key: request.key,
  value: request.value
});
const marshalCreateEmailRequest = (request, defaults) => ({
  additional_headers: request.additionalHeaders !== void 0 ? request.additionalHeaders.map(
    (elt) => marshalCreateEmailRequestHeader(elt)
  ) : void 0,
  attachments: request.attachments !== void 0 ? request.attachments.map(
    (elt) => marshalCreateEmailRequestAttachment(elt)
  ) : void 0,
  bcc: request.bcc !== void 0 ? request.bcc.map((elt) => marshalCreateEmailRequestAddress(elt)) : void 0,
  cc: request.cc !== void 0 ? request.cc.map((elt) => marshalCreateEmailRequestAddress(elt)) : void 0,
  from: marshalCreateEmailRequestAddress(request.from),
  html: request.html,
  project_id: request.projectId ?? defaults.defaultProjectId,
  send_before: request.sendBefore,
  subject: request.subject,
  text: request.text,
  to: request.to !== void 0 ? request.to.map((elt) => marshalCreateEmailRequestAddress(elt)) : void 0
});
const marshalUpdateWebhookRequest = (request, defaults) => ({
  event_types: request.eventTypes !== void 0 ? request.eventTypes : void 0,
  name: request.name,
  sns_arn: request.snsArn
});
export {
  marshalCreateDomainRequest,
  marshalCreateEmailRequest,
  marshalUpdateWebhookRequest,
  unmarshalCreateEmailResponse,
  unmarshalDomain,
  unmarshalDomainLastStatus,
  unmarshalEmail,
  unmarshalListDomainsResponse,
  unmarshalListEmailsResponse,
  unmarshalListWebhookEventsResponse,
  unmarshalListWebhooksResponse,
  unmarshalStatistics,
  unmarshalWebhook
};
